| Title: | Fit, Simulate and Diagnose Exponential-Family Models for Rank-Order Relational Data |
|---|---|
| Description: | A set of extensions for the 'ergm' package to fit weighted networks whose edge weights are ranks. See Krivitsky and Butts (2017) <doi:10.1177/0081175017692623> and Krivitsky, Hunter, Morris, and Klumb (2023) <doi:10.18637/jss.v105.i06>. |
| Authors: | Pavel N. Krivitsky [aut, cre] (ORCID: <https://orcid.org/0000-0002-9101-3362>), Carter T. Butts [ctb], Mark S. Handcock [ctb], David R. Hunter [ctb] |
| Maintainer: | Pavel N. Krivitsky <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 4.1.2-1575 |
| Built: | 2026-05-21 10:57:31 UTC |
| Source: | https://github.com/statnet/ergm.rank |
ergm.rank is a set of extensions to package ergm to fit and simulate from exponential-family random graph models for networks whose edge weights are ranks.
Mainly, it implements the
CompleteOrder reference
measure for valued ERGMs (Krivitsky 2012; Krivitsky et al. 2023) and
provides some rank-order change statistics
(search.ergmTerms("ordinal") for a list)
(Krivitsky and Butts 2017).
When publishing results obtained using this package, please cite the
original authors as described in citation(package="ergm.rank").
All programs derived from this package must cite it.
This package contains functions specific to using ergm() to model
networks whose dyad values are ranks. Examples include preferences,
valued ties reduced to ranks, etc.. These terms have a specialized
interpretation, and are therefore generally prefixed by "rank.",
though they should take any valued data.
For detailed information on how to download and install the software, go to the Statnet project website: https://statnet.org. A tutorial, support newsgroup, references and links to further resources are provided there.
Maintainer: Pavel N. Krivitsky [email protected] (ORCID)
Other contributors:
Carter T. Butts [email protected] [contributor]
Mark S. Handcock [email protected] [contributor]
David R. Hunter [email protected] [contributor]
Krivitsky PN (2012).
“Exponential-family Random Graph Models for Valued Networks.”
Electronic Journal of Statistics, 6, 1100–1128.
doi:10.1214/12-EJS696.
Krivitsky PN, Butts CT (2017).
“Exponential-family Random Graph Models for Rank-order Relational Data.”
Sociological Methodology, 47(1), 68–112.
doi:10.1177/0081175017692623.
Krivitsky PN, Hunter DR, Morris M, Klumb C (2023).
“ergm 4: New Features for Analyzing Exponential-Family Random Graph Models.”
Journal of Statistical Software, 105(6), 1–44.
doi:10.18637/jss.v105.i06.
The network must be directed or bipartite, and the ordering of the alters by each ego must be complete, i.e., there must not be any ties.
# CompleteOrder# CompleteOrder
ergmReference for index of reference distributions currently visible to the package.
None
These 14 networks record weekly sociometric preference rankings from 17 men attending the University of Michigan in the fall of 1956; Data were collected longitudinally over 15 weeks, although data from week 9 are missing.
A list of 15 networks.
The men were recruited to live in off-campus (fraternity) housing, rented for them as part of the Michigan Group Study Project supervised by Theodore Newcomb from 1953 to 1956. All were incoming transfer students with no prior acquaintance of one another.
The data set, derived from one in the unreleased netdata package,
contains a network list newcomb with 14 networks. Each network is
complete and contains two edge attributes:
"rank"the preference of the th man for the th
man from 1 through 16, with 1 being the highest
preference.
"descrank"the same, but 1 indicates lowest
preference.
If the source of the data set does not specified otherwise, this data set is protected by the Creative Commons License https://creativecommons.org/licenses/by-nc-nd/2.5/.
When publishing results obtained using this data set the original authors should be cited. In addition this should be cited as:
Vladimir Batagelj and Andrej Mrvar (2006): Pajek datasets
https://github.com/bavla/Nets/tree/master/data/Pajek
https://github.com/bavla/Nets/blob/master/data/Pajek/ucinet/README.md
See the link above. Newcomb T. (1961). The acquaintance process. New York: Holt, Reinhard and Winston.
Nordlie P. (1958). A longitudinal study of interpersonal attraction in a natural group setting. Unpublished doctoral dissertation, University of Michigan.
White H., Boorman S. and Breiger R. (1977). Social structure from multiple networks, I. Blockmodels of roles and positions. American Journal of Sociology, 81, 730-780.
# Note: This takes a long time. data(newcomb) # Fit a model for the transition between initial (time 0) ranking and # ranking after one week (time 1). Note that MCMC interval has been # decreased to save time. newcomb.1.2.fit <- ergm(newcomb[[2]]~ rank.inconsistency(newcomb[[1]],"descrank")+ rank.deference+rank.nonconformity("all")+ rank.nonconformity("localAND"), response="descrank", reference=~CompleteOrder, control=control.ergm(MCMC.interval=10)) # Check MCMC diagnostics (barely adequate). mcmc.diagnostics(newcomb.1.2.fit) summary(newcomb.1.2.fit)# Note: This takes a long time. data(newcomb) # Fit a model for the transition between initial (time 0) ranking and # ranking after one week (time 1). Note that MCMC interval has been # decreased to save time. newcomb.1.2.fit <- ergm(newcomb[[2]]~ rank.inconsistency(newcomb[[1]],"descrank")+ rank.deference+rank.nonconformity("all")+ rank.nonconformity("localAND"), response="descrank", reference=~CompleteOrder, control=control.ergm(MCMC.interval=10)) # Check MCMC diagnostics (barely adequate). mcmc.diagnostics(newcomb.1.2.fit) summary(newcomb.1.2.fit)
Measures the
amount of "deference" in the network: configurations where an ego
ranks an alter over another alter , but
, in turn, ranks over . A lower-than-chance
value of this statistic and/or a negative coefficient implies a form
of mutuality in the network.
# valued: rank.deference# valued: rank.deference
ergmTerm for index of model terms currently visible to the package.
None
Models the effect of a dyadic covariate on the propensity of an ego
to rank alter highly.
# valued: rank.edgecov(x, attrname)# valued: rank.edgecov(x, attrname)
x, attrname
|
a specification for the dyadic covariate: either one of the following, or the name of a network attribute containing one of the following:
|
ergmTerm for index of model terms currently visible to the package.
None
Measures the amount of disagreement between rankings of the focus
network and a fixed covariate network x , by couting the number of pairwise
comparisons for which the two networks disagree.
# valued: rank.inconsistency(x, attrname, weights, wtname, wtcenter)# valued: rank.inconsistency(x, attrname, weights, wtname, wtcenter)
x, attrname
|
a specification for the reference ranking: either one of the following, or the name of a network attribute containing one of the following:
|
weights |
optional parameter to weigh the counts. Can be either a 3D |
wtname, wtcenter
|
If |
ergmTerm for index of model terms currently visible to the package.
None
Models the effect of one or more nodal covariates on the propensity of an actor to be ranked highly by the others.
# valued: rank.nodeicov(attr)# valued: rank.nodeicov(attr)
attr |
a vertex attribute specification (see Specifying Vertex attributes and Levels ( |
ergmTerm for index of model terms currently visible to the package.
None
Measures the amount of "nonconformity" in the network: configurations where an ego
ranks an alter over another alter , but
ego ranks over .
# valued: rank.nonconformity(to, par)# valued: rank.nonconformity(to, par)
to |
which controls to whom an ego may conform:
|
par |
additional parameters for some types of nonconformity. |
ergmTerm for index of model terms currently visible to the package.
None